Exception: SimpleOAuth::InvalidOptionsError
- Inherits:
-
StandardError
- Object
- StandardError
- SimpleOAuth::InvalidOptionsError
- Defined in:
- lib/simple_oauth/errors.rb
Overview
Error raised when invalid options are passed to Header
Error raised when invalid options are passed to Header